;; Generated package description from el-search.el  -*- no-byte-compile: t -*-
(define-package "el-search" "1.12.6.1" "Expression based interactive search for Emacs Lisp" '((emacs "25") (stream "2.2.4") (cl-print "1.0")) :commit "43779b910025aba2574213cf3eabee2132c0a175" :url "https://elpa.gnu.org/packages/el-search.html" :authors '(("Michael Heerdegen" . "michael_heerdegen@web.de")) :maintainer '("Michael Heerdegen" . "michael_heerdegen@web.de") :keywords '("lisp"))
